/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/
package kieker.webgui.converter;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.FacesConverter;

import kieker.analysis.model.analysisMetaModel.MIProject;

/**
 * This converter can be used to convert an instance of <i>MIProject</i> to a human readable string, but <b>not</b> vice versa.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@FacesConverter(value = MIProjectToStringConverter.NAME)
public class MIProjectToStringConverter implements Converter {

	/**
	 * This is the name of this converter.
	 */
	public static final String NAME = "kieker.webgui.converter.MIProjectToStringConverter";

	/**
	 * Creates a new instance of this class.
	 */
	public MIProjectToStringConverter() {
		/* No code necessary. */
	}

	/**
	 * This method delivers always null and should not be used.
	 * 
	 * @param fc
	 *            The FacesContext for the request being processed.
	 * @param uic
	 *            The component with which this model object value is
	 *            associated.
	 * @param string
	 *            The string to be converted.
	 * @return null
	 */
	@Override
	public Object getAsObject(final FacesContext fc, final UIComponent uic, final String string) {
		return null;
	}

	/**
	 * This method delivers the name of the given object, if the object is not
	 * null and the object is an instance of the class <code>MIProject</code>.
	 * 
	 * @param fc
	 *            The FacesContext for the request being processed.
	 * @param uic
	 *            The component with which this model object value is
	 *            associated.
	 * @param o
	 *            The object to be converted.
	 * @return A human readable representation of the given object if possible,
	 *         null otherwise.
	 */
	@Override
	public String getAsString(final FacesContext fc, final UIComponent uic, final Object o) {
		/*
		 * Make sure that the given object is well-defined.
		 */
		if (!(o instanceof MIProject)) {
			return "";
		} else {
			return ((MIProject) o).getName();
		}
	}
}
